'use strict';

exports.__esModule = true;

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; /*
                                                                                                                                                                                                                                                                   * This file is part of the nivo project.
                                                                                                                                                                                                                                                                   *
                                                                                                                                                                                                                                                                   * Copyright 2016-present, Raphaël Benitte.
                                                                                                                                                                                                                                                                   *
                                                                                                                                                                                                                                                                   * For the full copyright and license information, please view the LICENSE
                                                                                                                                                                                                                                                                   * file that was distributed with this source code.
                                                                                                                                                                                                                                                                   */


var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _reactMotion = require('react-motion');

var _colors = require('../../../lib/colors');

var _props = require('./props');

var _enhance = require('./enhance');

var _enhance2 = _interopRequireDefault(_enhance);

var _Container = require('../Container');

var _Container2 = _interopRequireDefault(_Container);

var _SvgWrapper = require('../SvgWrapper');

var _SvgWrapper2 = _interopRequireDefault(_SvgWrapper);

var _Grid = require('../../axes/Grid');

var _Grid2 = _interopRequireDefault(_Grid);

var _Axes = require('../../axes/Axes');

var _Axes2 = _interopRequireDefault(_Axes);

var _HeatMapCellRect = require('./HeatMapCellRect');

var _HeatMapCellRect2 = _interopRequireDefault(_HeatMapCellRect);

var _HeatMapCellCircle = require('./HeatMapCellCircle');

var _HeatMapCellCircle2 = _interopRequireDefault(_HeatMapCellCircle);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var HeatMap = function HeatMap(_ref) {
    var data = _ref.data,
        getIndex = _ref.getIndex,
        keys = _ref.keys,
        cellWidth = _ref.cellWidth,
        cellHeight = _ref.cellHeight,
        sizeScale = _ref.sizeScale,
        xScale = _ref.xScale,
        yScale = _ref.yScale,
        offsetX = _ref.offsetX,
        offsetY = _ref.offsetY,
        margin = _ref.margin,
        width = _ref.width,
        height = _ref.height,
        outerWidth = _ref.outerWidth,
        outerHeight = _ref.outerHeight,
        cellShape = _ref.cellShape,
        cellOpacity = _ref.cellOpacity,
        cellBorderWidth = _ref.cellBorderWidth,
        getCellBorderColor = _ref.getCellBorderColor,
        axisTop = _ref.axisTop,
        axisRight = _ref.axisRight,
        axisBottom = _ref.axisBottom,
        axisLeft = _ref.axisLeft,
        enableGridX = _ref.enableGridX,
        enableGridY = _ref.enableGridY,
        getLabelTextColor = _ref.getLabelTextColor,
        theme = _ref.theme,
        colorScale = _ref.colorScale,
        animate = _ref.animate,
        motionStiffness = _ref.motionStiffness,
        motionDamping = _ref.motionDamping,
        isInteractive = _ref.isInteractive;

    var Cell = void 0;
    if (cellShape === 'rect') {
        Cell = _HeatMapCellRect2.default;
    } else if (cellShape === 'circle') {
        Cell = _HeatMapCellCircle2.default;
    } else {
        Cell = cellShape;
    }

    var nodes = data.reduce(function (acc, d) {
        keys.forEach(function (key) {
            acc.push({
                key: key + '.' + getIndex(d),
                xKey: key,
                yKey: getIndex(d),
                x: xScale(key),
                y: yScale(getIndex(d)),
                width: sizeScale ? Math.min(sizeScale(d[key]) * cellWidth, cellWidth) : cellWidth,
                height: sizeScale ? Math.min(sizeScale(d[key]) * cellHeight, cellHeight) : cellHeight,
                value: d[key],
                color: colorScale(d[key])
            });
        });

        return acc;
    }, []);

    var motionProps = {
        animate: animate,
        motionDamping: motionDamping,
        motionStiffness: motionStiffness
    };

    var cells = void 0;
    if (animate === true) {
        cells = _react2.default.createElement(
            _reactMotion.TransitionMotion,
            {
                styles: nodes.map(function (node) {
                    return {
                        key: node.key,
                        data: node,
                        style: _extends({
                            x: (0, _reactMotion.spring)(node.x, motionProps),
                            y: (0, _reactMotion.spring)(node.y, motionProps),
                            width: (0, _reactMotion.spring)(node.width, motionProps),
                            height: (0, _reactMotion.spring)(node.height, motionProps)
                        }, (0, _colors.colorMotionSpring)(node.color, motionProps))
                    };
                })
            },
            function (interpolatedStyles) {
                return _react2.default.createElement(
                    'g',
                    null,
                    interpolatedStyles.map(function (_ref2) {
                        var key = _ref2.key,
                            style = _ref2.style,
                            node = _ref2.data;

                        var color = (0, _colors.getInterpolatedColor)(style);

                        return _react2.default.createElement(Cell, {
                            key: key,
                            value: node.value,
                            x: style.x,
                            y: style.y,
                            width: Math.max(style.width, 0),
                            height: Math.max(style.height, 0),
                            color: color,
                            opacity: cellOpacity,
                            borderWidth: cellBorderWidth,
                            borderColor: getCellBorderColor(_extends({}, node, { color: color })),
                            textColor: getLabelTextColor(_extends({}, node, { color: color }))
                        });
                    })
                );
            }
        );
    } else {
        cells = nodes.map(function (node) {
            return _react2.default.createElement(Cell, {
                key: node.key,
                value: node.value,
                x: node.x,
                y: node.y,
                width: node.width,
                height: node.height,
                color: node.color,
                opacity: cellOpacity,
                borderWidth: cellBorderWidth,
                borderColor: getCellBorderColor(node),
                textColor: getLabelTextColor(node)
            });
        });
    }

    return _react2.default.createElement(
        _Container2.default,
        { isInteractive: isInteractive, theme: theme },
        function (_ref3) {
            var showTooltip = _ref3.showTooltip,
                hideTooltip = _ref3.hideTooltip;

            return _react2.default.createElement(
                _SvgWrapper2.default,
                {
                    width: outerWidth,
                    height: outerHeight,
                    margin: Object.assign({}, margin, {
                        top: margin.top + offsetY,
                        left: margin.left + offsetX
                    })
                },
                _react2.default.createElement(_Grid2.default, _extends({
                    theme: theme,
                    width: width - offsetX * 2,
                    height: height - offsetY * 2,
                    xScale: enableGridX ? xScale : null,
                    yScale: enableGridY ? yScale : null
                }, motionProps)),
                _react2.default.createElement(_Axes2.default, _extends({
                    xScale: xScale,
                    yScale: yScale,
                    width: width,
                    height: height,
                    theme: theme,
                    top: axisTop,
                    right: axisRight,
                    bottom: axisBottom,
                    left: axisLeft
                }, motionProps)),
                cells
            );
        }
    );
};

HeatMap.propTypes = _props.HeatMapPropTypes;

exports.default = (0, _enhance2.default)(HeatMap);